<?php
/**
 * A command for profile-update handling
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 Ship-Simu Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class WebShipsimuProfileCommand extends BaseCommand implements Commandable {
	/**
	 * Filtered request data
	 */
	private $requestData = array();

	/**
	 * Allowed profile data to pass through
	 */
	private $allowedData = array(
		'pass'  => 'pass1',
		'email' => 'email1',
		'surname',
		'family',
		'street',
		'city',
		'zip',
		'icq',
		'jabber',
		'yahoo',
		'aol',
		'msn',
		'rules'
	);

	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Clean up a little
		$this->removeNumberFormaters();
		$this->removeSystemArray();
	}

	/**
	 * Creates an instance of this command and sets the resolver instance
	 *
	 * @param	$resolverInstance	An instance of a command resolver
	 * @return	$commandInstance	The created command instance
	 */
	public final static function createWebShipsimuProfileCommand (CommandResolver $resolverInstance) {
		// Get a new instance
		$commandInstance = new WebShipsimuProfileCommand();

		// Set the resolver instance
		$commandInstance->setResolverInstance($resolverInstance);

		// Return the prepared instance
		return $commandInstance;
	}

	/**
	 * Executes the command with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 * @todo	Add functionality here
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		// Make sure only allowed values are comming through
		foreach ($this->allowedData as $alias => $element) {
			// Get data
			$data = $requestInstance->getRequestElement($element);

			// Silently skip empty fields
			if (empty($data)) continue;

			// Do we have an alias?
			if (is_string($alias)) {
				// Yes, so use it
				$this->requestData[$alias]   = $data;
			} else {
				// No, default entry
				$this->requestData[$element] = $data;
			}
		} // END - foreach

		// Remove the array, we don't need it anymore
		unset($this->allowedData);

		// Unfinished!
		$this->partialStub("Unfinished work.");
		$this->debugBackTrace();
	}

	/**
	 * Adds extra filters to the given controller instance
	 *
	 * @param	$controllerInstance		A controller instance
	 * @param	$requestInstance		An instance of a class with an Requestable interface
	 * @return	void
	 * @todo	Add some more pre/post filters to the controller
	 */
	public function addExtraFilters (Controller $controllerInstance, Requestable $requestInstance) {
		// Add user auth filter (we don't need an update of the user here because it will be redirected)
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('user_auth_filter'));

		// User status filter
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('user_status_filter'));

		// Updated rules accepted
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('rules_accepted_filter'));

		// Account password validation
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('account_password_filter'));

		// Validate CAPTCHA input
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('captcha_profile_verifier_filter'));

		// Validate birthday input
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('birthday_profile_verifier_filter'));

		// Email changed
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('email_change_filter'));

		// Password changed
		$controllerInstance->addPreFilter(ObjectFactory::createObjectByConfiguredName('password_change_filter'));
	}
}

// [EOF]
?>
