<?php
/**
 * A passenger ship with one or more decks, cabins, bridge (replacement for the
 * captain) and many more
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 Ship-Simu Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class PassengerShip extends BaseShip implements ConstructableShip {
	// Konstruktor
	protected function __construct () {
		// Eltern-Kontruktor aufrufen
		parent::__construct(__CLASS__);

		// Clean up a little
		$this->removeSystemArray();
		$this->removeNumberFormaters();
	}

	// Passagier-Schiff erstellen
	public final static function createPassengerShip ($shipName) {
		// Get new instance
		$passInstance = new PassengerShip();

		// Set ship name
		$passInstance->setShipName($shipName);

		// Instanz zurueckgeben
		return $passInstance;
	}

	// Anzahl Betten ermitteln
	public final function calcTotalBeds () {
		// Struktur-Array holen
		$struct = $this->getStructuresArray();

		if (is_null($struct)) {
			// Empty structures list!
			throw new EmptyStructuresListException($this, self::EXCEPTION_EMPTY_STRUCTURES_ARRAY);
		} // END - if

		// Anzahl Betten auf 0 setzen
		$numBeds = 0;

		// Alle Strukturen nach Kabinen durchsuchen
		for ($idx = $struct->getIterator(); $idx->valid(); $idx->next()) {
			// Element holen
			$el = $idx->current();

			// Ist es eine Kabine?
			if ($el->isCabin()) {
				// Anzahl Betten ermitteln
				$total = $el->calcTotalBedsByCabin();
				$numBeds += $total;

				// Debug-Meldung ausgeben?
				if ((defined('DEBUG_SHIP')) || (defined('DEBUG_ALL'))) {
					// Get new instance
					$cabType = "Kabine ohne Namen";
					$cab = $el->getPartInstance();
					if (!is_null($cab)) {
						// Kabinenbeschreibung holen
						$cabType = $cab->getObjectDescription();
					} // END - if
				} // END - if
			} // END - if
		} // END - for

		// Anzahl zurueckliefern
		return $numBeds;
	}
}

// [EOF]
?>
